@@ -188,6 +188,7 @@ func runStart(cmd *cobra.Command, args []string) {
 
 	validateSpecifiedDriver(existing)
 	validateKubernetesVersion(existing)
+	validateContainerRuntime(existing)
 
 	ds, alts, specified := selectDriver(existing)
 	if cmd.Flag(kicBaseImage).Changed {
@@ -270,7 +271,7 @@ func runStart(cmd *cobra.Command, args []string) {
 		exit.Error(reason.GuestStart, "failed to start node", err)
 	}
 
-	if err := showKubectlInfo(kubeconfig, starter.Node.KubernetesVersion, starter.Cfg.Name); err != nil {
+	if err := showKubectlInfo(kubeconfig, starter.Node.KubernetesVersion, starter.Node.ContainerRuntime, starter.Cfg.Name); err != nil {
 		klog.Errorf("kubectl info: %v", err)
 	}
 }
@@ -302,7 +303,8 @@ func provisionWithDriver(cmd *cobra.Command, ds registry.DriverState, existing *
 	}
 
 	k8sVersion := getKubernetesVersion(existing)
-	cc, n, err := generateClusterConfig(cmd, existing, k8sVersion, driverName)
+	rtime := getContainerRuntime(existing)
+	cc, n, err := generateClusterConfig(cmd, existing, k8sVersion, rtime, driverName)
 	if err != nil {
 		return node.Starter{}, errors.Wrap(err, "Failed to generate config")
 	}
@@ -381,6 +383,7 @@ func startWithDriver(cmd *cobra.Command, starter node.Starter, existing *config.
 						Worker:            true,
 						ControlPlane:      false,
 						KubernetesVersion: starter.Cfg.KubernetesConfig.KubernetesVersion,
+						ContainerRuntime:  starter.Cfg.KubernetesConfig.ContainerRuntime,
 					}
 					out.Ln("") // extra newline for clarity on the command line
 					err := node.Add(starter.Cfg, n, viper.GetBool(deleteOnFailure))
@@ -439,15 +442,15 @@ func displayEnviron(env []string) {
 	}
 }
 
-func showKubectlInfo(kcs *kubeconfig.Settings, k8sVersion, machineName string) error {
+func showKubectlInfo(kcs *kubeconfig.Settings, k8sVersion, rtime, machineName string) error {
 	if k8sVersion == constants.NoKubernetesVersion {
 		register.Reg.SetStep(register.Done)
 		out.Step(style.Ready, "Done! minikube is ready without Kubernetes!")
 
 		// Runtime message.
 		boxConfig := box.Config{Py: 1, Px: 4, Type: "Round", Color: "Green"}
-		switch viper.GetString(containerRuntime) {
-		case constants.DefaultContainerRuntime:
+		switch rtime {
+		case constants.Docker:
 			out.BoxedWithConfig(boxConfig, style.Tip, "Things to try without Kubernetes ...", `- "minikube ssh" to SSH into minikube's node.
 - "minikube docker-env" to point your docker-cli to the docker inside minikube.
 - "minikube image" to build images without docker.`)
@@ -1183,9 +1186,10 @@ func validateFlags(cmd *cobra.Command, drvName string) {
 			exit.Message(reason.DrvUnsupportedProfile, "The '{{.name}} driver does not support multiple profiles: https://minikube.sigs.k8s.io/docs/reference/drivers/none/", out.V{"name": drvName})
 		}
 
-		runtime := viper.GetString(containerRuntime)
-		if runtime != "docker" {
-			out.WarningT("Using the '{{.runtime}}' runtime with the 'none' driver is an untested configuration!", out.V{"runtime": runtime})
+		// default container runtime varies, starting with Kubernetes 1.24 - assume that only the default container runtime has been tested
+		rtime := viper.GetString(containerRuntime)
+		if rtime != constants.DefaultContainerRuntime && rtime != defaultRuntime(getKubernetesVersion(nil)) {
+			out.WarningT("Using the '{{.runtime}}' runtime with the 'none' driver is an untested configuration!", out.V{"runtime": rtime})
 		}
 
 		// conntrack is required starting with Kubernetes 1.18, include the release candidates for completion
@@ -1285,6 +1289,10 @@ func validateRuntime(rtime string) error {
 	// `crio` is accepted as an alternative spelling to `cri-o`
 	validOptions = append(validOptions, constants.CRIO)
 
+	if rtime == constants.DefaultContainerRuntime {
+		return nil
+	}
+
 	var validRuntime bool
 	for _, option := range validOptions {
 		if rtime == option {
@@ -1299,7 +1307,7 @@ func validateRuntime(rtime string) error {
 	}
 
 	if (rtime == "crio" || rtime == "cri-o") && (strings.HasPrefix(runtime.GOARCH, "ppc64") || detect.RuntimeArch() == "arm" || strings.HasPrefix(detect.RuntimeArch(), "arm/")) {
-		return errors.Errorf("The %s runtime is not compatible with the %s architecture. See https://github.com/cri-o/cri-o/issues/2467 for more details.", rtime, runtime.GOARCH)
+		return errors.Errorf("The %s runtime is not compatible with the %s architecture. See https://github.com/cri-o/cri-o/issues/2467 for more details", rtime, runtime.GOARCH)
 	}
 
 	if !validRuntime {
@@ -1308,9 +1316,31 @@ func validateRuntime(rtime string) error {
 	return nil
 }
 
+func getContainerRuntime(old *config.ClusterConfig) string {
+	paramRuntime := viper.GetString(containerRuntime)
+
+	// try to load the old version first if the user didn't specify anything
+	if paramRuntime == constants.DefaultContainerRuntime && old != nil {
+		paramRuntime = old.KubernetesConfig.ContainerRuntime
+	}
+
+	if paramRuntime == constants.DefaultContainerRuntime {
+		k8sVersion := getKubernetesVersion(old)
+		paramRuntime = defaultRuntime(k8sVersion)
+	}
+
+	return paramRuntime
+}
+
+// defaultRuntime returns the default container runtime
+func defaultRuntime(k8sVersion string) string {
+	// minikube default
+	return constants.Docker
+}
+
 // if container runtime is not docker, check that cni is not disabled
 func validateCNI(cmd *cobra.Command, runtime string) {
-	if runtime == "docker" {
+	if runtime == constants.Docker {
 		return
 	}
 	if cmd.Flags().Changed(cniFlag) && strings.ToLower(viper.GetString(cniFlag)) == "false" {
@@ -1378,32 +1408,39 @@ func validateRegistryMirror() {
 // args match the format of registry.cn-hangzhou.aliyuncs.com/google_containers
 // also "<hostname>[:<port>]"
 func validateImageRepository(imageRepo string) (validImageRepo string) {
+	expression := regexp.MustCompile(`^(?:(\w+)\:\/\/)?([-a-zA-Z0-9]{1,}(?:\.[-a-zA-Z]{1,}){0,})(?:\:(\d+))?(\/.*)?$`)
 
 	if strings.ToLower(imageRepo) == "auto" {
-		validImageRepo = "auto"
+		imageRepo = "auto"
 	}
-	URL, err := url.Parse(imageRepo)
 
-	if err != nil {
-		klog.Errorln("Error Parsing URL: ", err)
+	if !expression.MatchString(imageRepo) {
+		klog.Errorln("Provided repository is not a valid URL. Defaulting to \"auto\"")
+		imageRepo = "auto"
 	}
 
 	var imageRepoPort string
+	groups := expression.FindStringSubmatch(imageRepo)
 
-	if URL.Port() != "" && strings.Contains(imageRepo, ":"+URL.Port()) {
-		imageRepoPort = ":" + URL.Port()
+	scheme := groups[1]
+	hostname := groups[2]
+	port := groups[3]
+	path := groups[4]
+
+	if port != "" && strings.Contains(imageRepo, ":"+port) {
+		imageRepoPort = ":" + port
 	}
 
 	// tips when imageRepo ended with a trailing /.
 	if strings.HasSuffix(imageRepo, "/") {
-		out.Infof("The --image-repository flag your provided ended with a trailing / that could cause conflict in kuberentes, removed automatically")
+		out.Infof("The --image-repository flag your provided ended with a trailing / that could cause conflict in kubernetes, removed automatically")
 	}
 	// tips when imageRepo started with scheme such as http(s).
-	if URL.Scheme != "" {
-		out.Infof("The --image-repository flag your provided contains Scheme: {{.scheme}}, which will be removed automatically", out.V{"scheme": URL.Scheme})
+	if scheme != "" {
+		out.Infof("The --image-repository flag you provided contains Scheme: {{.scheme}}, which will be removed automatically", out.V{"scheme": scheme})
 	}
 
-	validImageRepo = URL.Hostname() + imageRepoPort + strings.TrimSuffix(URL.Path, "/")
+	validImageRepo = hostname + imageRepoPort + strings.TrimSuffix(path, "/")
 
 	return validImageRepo
 }
@@ -1458,6 +1495,7 @@ func createNode(cc config.ClusterConfig, kubeNodeName string, existing *config.C
 	if existing != nil {
 		cp, err := config.PrimaryControlPlane(existing)
 		cp.KubernetesVersion = getKubernetesVersion(&cc)
+		cp.ContainerRuntime = getContainerRuntime(&cc)
 		if err != nil {
 			return cc, config.Node{}, err
 		}
@@ -1467,6 +1505,7 @@ func createNode(cc config.ClusterConfig, kubeNodeName string, existing *config.C
 		nodes := []config.Node{}
 		for _, n := range existing.Nodes {
 			n.KubernetesVersion = getKubernetesVersion(&cc)
+			n.ContainerRuntime = getContainerRuntime(&cc)
 			nodes = append(nodes, n)
 		}
 		cc.Nodes = nodes
@@ -1477,6 +1516,7 @@ func createNode(cc config.ClusterConfig, kubeNodeName string, existing *config.C
 	cp := config.Node{
 		Port:              cc.KubernetesConfig.NodePort,
 		KubernetesVersion: getKubernetesVersion(&cc),
+		ContainerRuntime:  getContainerRuntime(&cc),
 		Name:              kubeNodeName,
 		ControlPlane:      true,
 		Worker:            true,
@@ -1526,12 +1566,23 @@ func validateKubernetesVersion(old *config.ClusterConfig) {
 	nvs, _ := semver.Make(strings.TrimPrefix(getKubernetesVersion(old), version.VersionPrefix))
 	oldestVersion := semver.MustParse(strings.TrimPrefix(constants.OldestKubernetesVersion, version.VersionPrefix))
 	defaultVersion := semver.MustParse(strings.TrimPrefix(constants.DefaultKubernetesVersion, version.VersionPrefix))
+	newestVersion := semver.MustParse(strings.TrimPrefix(constants.NewestKubernetesVersion, version.VersionPrefix))
 	zeroVersion := semver.MustParse(strings.TrimPrefix(constants.NoKubernetesVersion, version.VersionPrefix))
 
 	if nvs.Equals(zeroVersion) {
 		klog.Infof("No Kuberentes version set for minikube, setting Kubernetes version to %s", constants.NoKubernetesVersion)
 		return
 	}
+	if nvs.Major > newestVersion.Major {
+		out.WarningT("Specified Major version of Kubernetes {{.specifiedMajor}} is newer than the newest supported Major version: {{.newestMajor}}", out.V{"specifiedMajor": nvs.Major, "newestMajor": newestVersion.Major})
+		if !viper.GetBool(force) {
+			out.WarningT("You can force an unsupported Kubernetes version via the --force flag")
+		}
+		exitIfNotForced(reason.KubernetesTooNew, "Kubernetes {{.version}} is not supported by this release of minikube", out.V{"version": nvs})
+	}
+	if nvs.GT(newestVersion) {
+		out.WarningT("Specified Kubernetes version {{.specified}} is newer than the newest supported version: {{.newest}}", out.V{"specified": nvs, "newest": constants.NewestKubernetesVersion})
+	}
 	if nvs.LT(oldestVersion) {
 		out.WarningT("Specified Kubernetes version {{.specified}} is less than the oldest supported version: {{.oldest}}", out.V{"specified": nvs, "oldest": constants.OldestKubernetesVersion})
 		if !viper.GetBool(force) {
@@ -1573,6 +1624,17 @@ func validateKubernetesVersion(old *config.ClusterConfig) {
 	}
 }
 
+// validateContainerRuntime ensures that the container runtime is reasonable
+func validateContainerRuntime(old *config.ClusterConfig) {
+	if old == nil || old.KubernetesConfig.ContainerRuntime == "" {
+		return
+	}
+
+	if err := validateRuntime(old.KubernetesConfig.ContainerRuntime); err != nil {
+		klog.Errorf("Error parsing old runtime %q: %v", old.KubernetesConfig.ContainerRuntime, err)
+	}
+}
+
 func isBaseImageApplicable(drv string) bool {
 	return registry.IsKIC(drv)
 }
