@@ -96,6 +96,7 @@ type ClusterConfig struct {
 	MountType               string
 	MountUID                string
 	BinaryMirror            string // Mirror location for kube binaries (kubectl, kubelet, & kubeadm)
+	DisableOptimizations    bool
 }
 
 // KubernetesConfig contains the parameters used to configure the VM Kubernetes.
@@ -135,6 +136,7 @@ type Node struct {
 	IP                string
 	Port              int
 	KubernetesVersion string
+	ContainerRuntime  string
 	ControlPlane      bool
 	Worker            bool
 }
