@@ -143,7 +143,7 @@ func TestDownloadOnly(t *testing.T) {
 				}
 				// checking binaries downloaded (kubelet,kubeadm)
 				for _, bin := range constants.KubernetesReleaseBinaries {
-					fp := filepath.Join(localpath.MiniPath(), "cache", "linux", v, bin)
+					fp := filepath.Join(localpath.MiniPath(), "cache", "linux", runtime.GOARCH, v, bin)
 					_, err := os.Stat(fp)
 					if err != nil {
 						t.Errorf("expected the file for binary exist at %q but got error %v", fp, err)
@@ -161,7 +161,7 @@ func TestDownloadOnly(t *testing.T) {
 				if runtime.GOOS == "windows" {
 					binary = "kubectl.exe"
 				}
-				fp := filepath.Join(localpath.MiniPath(), "cache", runtime.GOOS, v, binary)
+				fp := filepath.Join(localpath.MiniPath(), "cache", runtime.GOOS, runtime.GOARCH, v, binary)
 				if _, err := os.Stat(fp); err != nil {
 					t.Errorf("expected the file for binary exist at %q but got error %v", fp, err)
 				}
